@@ -26,8 +26,12 @@
 
 #define PGrnMatchStrategyV2Number		12	/* operator &@	(@ in Groonga) */
 #define PGrnQueryStrategyV2Number		13	/* operator &?  (query in Groonga) */
-#define PGrnMatchContainStrategyNumber	14	/* operator &@> (@ in Groonga) */
-#define PGrnQueryContainStrategyNumber	15	/* operator &?> (query in Groonga) */
+#define PGrnSimilarStrategyV2Number		14	/* operator &~? (similar search) */
+#define PGrnScriptStrategyV2Number		15	/* operator &`  (script in Groonga) */
+#define PGrnPrefixStrategyV2Number		16	/* operator &^  (prefix search) */
+#define PGrnPrefixRKStrategyV2Number	17	/* operator &^~ (prefix RK search) */
+#define PGrnMatchContainStrategyNumber	18	/* operator &@> (@ in Groonga) */
+#define PGrnQueryContainStrategyNumber	19	/* operator &?> (query in Groonga) */
 
 /* file and table names */
 #define PGrnLogBasename					"pgroonga.log"
@@ -67,6 +71,10 @@ extern Datum PGDLLEXPORT pgroonga_match_jsonb(PG_FUNCTION_ARGS);
 /* v2 */
 extern Datum PGDLLEXPORT pgroonga_match_text(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_query_text(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_similar_text(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_script_text(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_prefix_text(PG_FUNCTION_ARGS);
+extern Datum PGDLLEXPORT pgroonga_prefix_rk_text(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_match_contain_text(PG_FUNCTION_ARGS);
 extern Datum PGDLLEXPORT pgroonga_query_contain_text(PG_FUNCTION_ARGS);
 
